from flask import Flask,render_template, url_for,request,redirect
import flask as f
from .crawler import CrawlerBot
import os
from .db import DataBase
#print(dir(request),[[i,dir(i)] for i in dir(request)])
app = Flask(__name__, template_folder='templates')
#db0=DataBase("search_data.db")
#table=db0.select_all_data()
#db0.reset()
def is_url(url):
    is_url=True
    if  " " in url:
        is_url=False
    return is_url
@app.route("/",methods=["GET","POST"])
def search():
    try:
        db0=DataBase("search_data.db")
        table= db0.select_all_data()
        url_body="" 
        if request.method=="GET":
            # return f"The submit condition is :== {request.args.get('submit','submit')}"
            if request.args.get("is-submitted","")=="Submit":
                #body=str(bot.get_content_from_urls([request.args.get("search-query","")])[0])
                url_body=request.args.get("search-query","")
                if is_url(url_body):
                    print(db0.insert_data(url_body))
                    return redirect(url_body)
            else:
                body=["abcdefghijklmnopqrstuvwxyz"][0]

        return render_template("index.html",url_body=url_body,table=table)
    except BaseException as e:
        # assert e
        return  f"<h1> The error is {e}"
@app.route("/admin",methods=["GET","POST"])
def admin_panel():
    operation=None
    company_name=None
    url=None
    submit=None
    db=DataBase("search_data.db")
    table=db.select_all_data()
    try:
        if request.method=="POST":
            if request.form["submit"]=="Submit":
                operation=request.form["operation"]
                company_name=request.form["company-name"]
                url=request.form["url"]
        if not operation==None:
            match operation:
                case "insert":
                    company_name=db.insert_data(url)
                case "update":
                    company_name=db.update_data(url)
                case _:
                    company_name=db.delete_data(url)
        return render_template("admin-panel.html",table=table,operation=operation,company_name=company_name,url=url)
    except BaseException as e:
        return str(e)
def main():
    #print(f"{'\033[91m'}|---\\##|--|                  |-->
    #print(f"{'\033[92m'}|####\\#|##|                  |__>
    #print(f"{'\033[93m'}|##|\\#\\|##|------  \\ ---- /   >
    #print(f"{'\033[94m'}|##| \\####| |--| |  \\ \\/ /   |>
    #print(f"{'\033[95m'}|##|  \\###| |__| |-- \\  /    | >
    #print(f"{'\033[96m'}|__|   \\__|______|__  \\/     |_>
    app.run(debug=True,host='0.0.0.0', port=5001)	
if __name__ == '__main__':
    pass
    #app.run(host="0.0.0.0",port=5000,debug=True)
    



import urllib.robotparser as u
from  urllib.parse import urlparse,urlsplit
import requests as r
from bs4 import BeautifulSoup as bs
class CrawlerBot:
    def __init__(self,name:str)->None:
        self.name=name
        self.robot_parser=u.RobotFileParser()
        self.headers = {
      'User-Agent': 'JJSRCrawlerBot/1.0 all.dart603@passinbox for inqueries'
        }
    def get_root_path(self,url):
        url1= urlsplit(url)
        root_url= f"{url1[0]}://{url1[1]}"
        return root_url

    def is_url_crawlable(self,url):
        url1= self.get_root_path(url)
        robot_url= f"{url1}/robots.txt"
        allowed_to_crawl=False
        try:
            with r.get(robot_url,headers=self.headers) as response:
                if response.status_code==200:
                    self.robot_parser.parse(response.text.splitlines())
                    self.robot_parser.modified()
                    #print(self.robot_parser.read())
                    if self.robot_parser.can_fetch("*",url):
                        #print("url is allowed to crawl")
                        allowed_to_crawl=True
                else:
                    allowed_to_crawl=True
        except BaseException as e:
            return str(e)
        return robot_url,allowed_to_crawl
    def get_content_from_urls(self,urls:list)->list:
        return_data_list=[]
        crawlable=self.is_url_crawlable
        response= [r.get(i,headers=self.headers) for i in urls if crawlable(i)[1]]
        #print(response[0].encoding,
        #[i for i in response[0].raw.read_chunked()],[dir(response[0].raw)],
        #dir(response[0]))
        for i in response:
            if i.status_code==200:
                soup=bs(i.content,"html.parser")
                url_data=[]
                url_data.append(soup.title.string if not soup.title==None else " ")
                url_data.append(soup.h1.string if not soup.h1 ==None else " ") 
                return_data_list.append(url_data)
            # print(soup.find("body"))
        return return_data_list
bot=CrawlerBot("JJSRBot")
urls=["https://shree-hari-satta.serv00.net/",
"https://comdotharman0.github.io/",
"https://satta-king-fast.com/"]
#print(bot.get_content_from_urls([urls[2]])




import sqlite3
from jjsr.crawler import CrawlerBot
class DataBase:
    def __init__(self,name):
        self.name=name
        self.con = sqlite3.connect(self.name)
        self.cur = self.con.cursor()
        self.setup()
    def setup(self):
        self.cur.execute("""CREATE TABLE IF NOT EXISTS URLS (
        url NOT NULL UNIQUE,
        title,
        description
        );
        """)
    def select_all_data(self):
        res = self.cur.execute("SELECT * FROM URLS;")
        return res.fetchall()
    def insert_data(self,url):
        try:
            bot=CrawlerBot("JJSRBOT")
            url_content= bot.get_content_from_urls([url])[0]
            data= [(url,url_content[0],url_content[1])]
            
            self.cur.executemany("INSERT INTO URLS VALUES(?, ?, ?)", data)
            self.con.commit()
            return f"{data} Inserted Successfully"
        except BaseException as e:
            return str(e)
    def update_data(self):
        pass
    def delete_data(self,url):
        try:
            self.cur.execute(f"DELETE FROM URLS WHERE url='{url}';")
            self.con.commit()
            return "Deleted Successfully"
        except BaseException as e:
            return str(e)
    def reset(self):
        try:
            self.cur.execute(f"DROP TABLE URLS;")
            self.con.commit()
            return "Reset Successfully"
        except BaseException as e:
            return str(e)
if __name__=="__main__":
    pass
